import { createRouter, createWebHistory } from 'vue-router';
import store from '@/stores/counter';
import axios from 'axios';
const router = createRouter({
  history: createWebHistory(import.meta.env.BASE_URL),
  routes: [
    {
      path: '/',
      redirect: '/login'
    },
    {
      path: '/login',
      name: 'login',
      meta: { title: '耗材管理系统-账号登录' },
      component: () => import('@/views/login/index.vue')
    },
    {
      path: '/homeIndex',
      meta: { title: '耗材管理系统-系统首页' },
      component: () => import('@/components/admin-frame/home.vue'),
      children: [
        {
          path: '/homeIndex',
          meta: { title: '耗材管理系统-系统首页' },
          component: () => import('@/views/home/index.vue')
        },
        {
          path: '/users/user',
          meta: { title: '普通用户管理' },
          component: () => import('@/views/users/user/index.vue')
        },
        {
          path: '/users/user/detail',
          meta: { title: '信息管理' },
          component: () => import('@/views/users/user/detail.vue')
        },
        {
          path: '/users/admin',
          meta: { title: '街道管理员管理' },
          component: () => import('@/views/users/admin/index.vue')
        },
        {
          path: '/users/admin/detail',
          meta: { title: '信息管理' },
          component: () => import('@/views/users/admin/detail.vue')
        },
        {
          path: '/users/firm',
          meta: { title: '厂商管理' },
          component: () => import('@/views/users/firm/index.vue')
        },
        {
          path: '/users/firm/detail',
          meta: { title: '信息管理' },
          component: () => import('@/views/users/firm/detail.vue')
        },
        {
          path: '/goods/index',
          meta: { title: '商品管理' },
          component: () => import('@/views/goods/index.vue')
        },
        {
          path: '/goods/detail',
          meta: { title: '商品信息管理' },
          component: () => import('@/views/goods/detail.vue')
        },
        {
          path: '/order/index',
          meta: { title: '订单管理' },
          component: () => import('@/views/order/index.vue')
        },
        {
          path: '/order/detail',
          meta: { title: '订单信息管理' },
          component: () => import('@/views/order/detail.vue')
        },
        {
          path: '/system/buy',
          meta: { title: '采购审批设置' },
          component: () => import('@/views/system/buy/index.vue')
        },
        {
          path: '/system/config',
          meta: { title: '基础设置' },
          component: () => import('@/views/system/config/index.vue')
        },
        {
          path: '/system/dict',
          meta: { title: '字典管理' },
          component: () => import('@/views/system/dict/index.vue')
        },
        {
          path: '/system/dictData',
          meta: { title: '字典数据管理' },
          component: () => import('@/views/system/dictData/index.vue')
        },
        {
          path: '/system/module',
          meta: { title: '首页模块设置' },
          component: () => import('@/views/system/module/index.vue')
        },
        {
          path: '/system/money',
          meta: { title: '回款审批设置' },
          component: () => import('@/views/system/money/index.vue')
        },
        {
          path: '/system/role',
          meta: { title: '角色设置' },
          component: () => import('@/views/system/role/index.vue')
        },
        {
          path: '/acccount/updatepd',
          meta: { title: '修改密码' },
          component: () => import('@/views/updatepd/index.vue')
        }
      ]
    }
  ]
});
router.beforeEach(async (to, from, next) => {
  document.title = `${to.meta.title} `;
  const token = localStorage.getItem('token');
  if (to.name != 'login') {
    if (token) {
      const res = await axios.request({
        method: 'get',
        url: '/ball/v1/api/token/tokenView',
        responseType: 'json',
        headers: {
          token: token
        }
      });
      if (res.data.errcode == '0') {
        store.commit('setUser', res.data.data, { root: true });
      }
      next();
    } else next('/login');
  } else next();
});

export default router;
